@@ -1,7 +1,7 @@
 package Finance::Currency::Convert::KlikBCA;
 
-our $DATE = '2015-09-03'; # DATE
-our $VERSION = '0.10'; # VERSION
+our $DATE = '2015-10-23'; # DATE
+our $VERSION = '0.11'; # VERSION
 
 use 5.010001;
 use strict;
@@ -16,8 +16,20 @@ our @EXPORT_OK = qw(get_currencies convert_currency);
 our %SPEC;
 
 $SPEC{get_currencies} = {
-    summary => 'Extract data from KlikBCA/BCA page',
     v => 1.1,
+    summary => 'Extract data from KlikBCA/BCA page',
+    result => {
+        description => <<'_',
+Will return a hash containing key `currencies`.
+
+The currencies is a hash with currency symbols as keys and prices as values.
+
+Tha values is a hash with these keys: `buy_bn` and `sell_bn` (Bank Note buy/sell
+rates), `buy_er` and `sell_er` (e-Rate buy/sell rates), `buy_ttc` and `sell_ttc`
+(Telegraphic Transfer Counter buy/sell rates).
+
+_
+    },
 };
 sub get_currencies {
     my %args = @_;
@@ -106,6 +118,7 @@ sub get_currencies {
 our $_get_res;
 
 $SPEC{convert_currency} = {
+    v => 1.1,
     summary => 'Convert currency using KlikBCA',
     args => {
         n => {
@@ -123,13 +136,25 @@ $SPEC{convert_currency} = {
             req => 1,
             pos => 2,
         },
+        which => {
+            summary => 'Select which rate to use (default is average buy+sell for e-Rate)',
+            schema => ['str*', in=>[map { my $bsa = $_; map {"${bsa}_$_"} qw(bn er ttc) } qw(buy sell avg)]],
+            description => <<'_',
+
+{buy,sell,avg}_{bn,er,ttc}.
+
+_
+            default => 'avg_er',
+            pos => 3,
+        },
     },
     args_as => 'array',
-    v => 1.1,
     result_naked => 1,
 };
 sub convert_currency {
-    my ($n, $from, $to) = @_;
+    my ($n, $from, $to, $which) = @_;
+
+    $which //= 'avg_er';
 
     unless ($_get_res) {
         $_get_res = get_currencies();
@@ -145,7 +170,15 @@ sub convert_currency {
     }
 
     my $c = $_get_res->[2]{currencies}{uc $from} or return undef;
-    $n * ($c->{sell_bn} + $c->{buy_bn}) / 2;
+
+    my $rate;
+    if ($which =~ /\Aavg_(.+)/) {
+        $rate = ($c->{"buy_$1"} + $c->{"sell_$1"}) / 2;
+    } else {
+        $rate = $c->{$which};
+    }
+
+    $n * $rate;
 }
 
 1;
@@ -163,7 +196,7 @@ Finance::Currency::Convert::KlikBCA - Convert currency using KlikBCA
 
 =head1 VERSION
 
-This document describes version 0.10 of Finance::Currency::Convert::KlikBCA (from Perl distribution Finance-Currency-Convert-KlikBCA), released on 2015-09-03.
+This document describes version 0.11 of Finance::Currency::Convert::KlikBCA (from Perl distribution Finance-Currency-Convert-KlikBCA), released on 2015-10-23.
 
 =head1 SYNOPSIS
 
@@ -192,10 +225,12 @@ Use get_currencies(), which actually retrieves and scrapes the source web page,
 if you need the more complete result.
 
 
-=head2 convert_currency($n, $from, $to) -> any
+=head2 convert_currency($n, $from, $to, $which) -> any
 
 Convert currency using KlikBCA.
 
+This function is not exported by default, but exportable.
+
 Arguments ('*' denotes required arguments):
 
 =over 4
@@ -206,6 +241,12 @@ Arguments ('*' denotes required arguments):
 
 =item * B<to>* => I<str>
 
+=item * B<which> => I<str> (default: "avg_er")
+
+Select which rate to use (default is average buy+sell for e-Rate).
+
+{buy,sell,avg}_{bn,er,ttc}.
+
 =back
 
 Return value:  (any)
@@ -215,6 +256,8 @@ Return value:  (any)
 
 Extract data from KlikBCA/BCA page.
 
+This function is not exported by default, but exportable.
+
 No arguments.
 
 Returns an enveloped result (an array).
@@ -228,6 +271,15 @@ that contains extra information.
 
 Return value:  (any)
 
+
+Will return a hash containing key C<currencies>.
+
+The currencies is a hash with currency symbols as keys and prices as values.
+
+Tha values is a hash with these keys: C<buy_bn> and C<sell_bn> (Bank Note buy/sell
+rates), C<buy_er> and C<sell_er> (e-Rate buy/sell rates), C<buy_ttc> and C<sell_ttc>
+(Telegraphic Transfer Counter buy/sell rates).
+
 =head1 SEE ALSO
 
 L<http://www.klikbca.com/>
